TosItem class

Single document inside a TosRequirement.

Constructors

TosItem({required TosItemType type, required bool required, required bool satisfied, String? url, String? content})
const
TosItem.fromDto(TosItemDto dto)
factory

Properties

content → String?
final
hashCode → int
The hash code for this object.
no setterinherited
required → bool
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
satisfied → bool
final
type → TosItemType
final
url → String?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited