TosItem class
Single document inside a TosRequirement.
Constructors
- TosItem({required TosItemType type, required bool required, required bool satisfied, String? url, String? content})
-
const
- TosItem.fromDto(TosItemDto dto)
-
factory
Properties
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited